.. image:: .github/resources/images/logo.png
    :width: 400 px
    :align: center

boa test constructor
--------------------
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   
.. image:: https://img.shields.io/python/required-version-toml?tomlFilePath=https://raw.githubusercontent.com/CityOfZion/boa-test-constructor/master/pyproject.toml
   :target: https://pypi.org/project/boa-test-constructor

This project provides a unittest class for testing NEO3 Blockchain smart contracts in style similar to unittest.IsolatedAsyncioTestCase.
It includes all necessary dependencies like a static binary of a `neo-go <https://github.com/nspcc-dev/neo-go>`_ node to run tests against ensuring the results are the same as on the real network.
